@@ -3,16 +3,16 @@
 #' @param user Pinnacle Username
 #' @param pwd  Pinnacle Password
 #'
-#' @import RCurl
 #'
-authorization <- function (user = as.character(GetCredentials()$Value[1]),
-                           pwd = as.character(GetCredentials()$Value[2])){
+authorization <- function (user,
+                           pwd){
   
     CheckTermsAndConditions()
-  
+    if(missing(user)) user <- GetUsername()
+    if(missing(pwd)) pwd <- GetPassword()
     credentials = paste(user,pwd,sep=":")
     credentials.r = charToRaw(enc2utf8(credentials))
-    paste0("Basic ", base64Encode(credentials.r, "character"))
+    paste0("Basic ", jsonlite::base64_enc(credentials.r))
 
   }
 
